@@ -1,11 +1,14 @@
 library(cluster)
+## Compare on these:
+nms <- c("clustering", "objective", "isolation", "clusinfo", "silinfo")
+nm2 <- c("medoids", nms)
 
 (x <- x0 <- cbind(V1 = (-3:4)^2, V2 = c(0:6,NA), V3 = c(1,2,NA,7,NA,8:9,8)))
 (px <- pam(x,2, metric="manhattan"))
 stopifnot(identical(x,x0))# DUP=FALSE ..
 pd <-  pam(dist(x,"manhattan"), 2)
 px2 <- pam(x,2, metric="manhattan", keep.diss=FALSE, keep.data=FALSE)
-nms <- c("clustering", "objective", "isolation", "clusinfo", "silinfo")
+
 stopifnot(identical(px[nms], pd[nms]),
           identical(px[nms], px2[nms]),
 	  ## and for default dist "euclidean":
@@ -22,7 +25,22 @@ x <- rbind(cbind(rnorm(120, 0,8), rnorm(120, 0,8)),
 .proctime00 <- proc.time()
 
 summary(px2 <- pam(x, 2))
-all.equal(px2[nms], pam(dist(x), 2)[nms], tol = 1e-12) ## TRUE
+pdx <- pam(dist(x), 2)
+all.equal(px2[nms], pdx[nms], tol = 1e-12) ## TRUE
+pdxK <- pam(dist(x), 2, keep.diss = TRUE)
+stopifnot(identical(pdx[nm2], pdxK[nm2]))
+
+spdx <- silhouette(pdx)
+summary(spdx)
+spdx
+if(FALSE)
+    plot(spdx)# the silhouette
+## is now identical :
+plot(pdx)# failed in 1.7.0 -- now only does silhouette
+
+## new `dist' argument needed for clusplot():
+plot(pdx, dist=dist(x))
+clusplot(pdx, dist=dist(x))
 
 data(ruspini)
 summary(pr4 <- pam(ruspini, 4))
